==> openurp-edu-api4j-0.0.25-sources.jar: org/openurp/code/geo/model/Country.java <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.code.geo.model;

import javax.persistence.Cacheable;
import javax.persistence.Entity;

import org.beangle.commons.entity.pojo.Code;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.openurp.code.nation;

/**
 * 国家地区
 *
 *
 * @since 2005-9-7
 */
@Entity(name = "org.openurp.code.geo.model.Country")
@Cacheable
@Cache(region = "eams.base", usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@nation
public class Country extends Code<Integer> {

  private static final long serialVersionUID = -8303016071363886718L;

  /** 中文简称 */
  private String shortName;

  /** 简码（三位） */
  private String alpha3Code;

  public Country() {
  }

  public Country(Integer id) {
    super(id);
  }

  public String getAlpha3Code() {
    return alpha3Code;
  }

  public void setAlpha3Code(String shortCode) {
    this.alpha3Code = shortCode;
  }

  public String getShortName() {
    return shortName;
  }

  public void setShortName(String shortName) {
    this.shortName = shortName;
  }

}

==> openurp-edu-api4j-0.31.1-sources.jar: org/openurp/code/geo/model/Country.java <==
/*
 * OpenURP, Agile University Resource Planning Solution.
 *
 * Copyright © 2014, The OpenURP Software.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful.
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.openurp.code.geo.model;

import javax.persistence.Cacheable;
import javax.persistence.Entity;

import org.beangle.commons.entity.pojo.Code;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.openurp.code.nation;

/**
 * 国家地区
 *
 *
 * @since 2005-9-7
 */
@Entity(name = "org.openurp.code.geo.model.Country")
@Cacheable
@Cache(region = "openurp.base", usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@nation
public class Country extends Code<Integer> {

  private static final long serialVersionUID = -8303016071363886718L;

  /** 中文简称 */
  private String shortName;

  /** 简码（三位） */
  private String alpha3Code;

  public Country() {
  }

  public Country(Integer id) {
    super(id);
  }

  public String getAlpha3Code() {
    return alpha3Code;
  }

  public void setAlpha3Code(String shortCode) {
    this.alpha3Code = shortCode;
  }

  public String getShortName() {
    return shortName;
  }

  public void setShortName(String shortName) {
    this.shortName = shortName;
  }

}
